---
name: "\U0001F41B Bug Report"
about: Submit a bug report to help us improve nc-time-axis
title: ''
labels: 'New: Issue, Type: Bug'
assignees: ''

---

## 🐛 Bug Report
<!-- Provide a clear description of what the bug is -->

## How to Reproduce
Steps to reproduce the behaviour:

1. 
2. 
3. 

## Expected Behaviour
<!-- A clear and concise description of what you expected to happen -->

## Environment 
 - OS & Version: [e.g., Ubuntu 20.04 LTS]
 - nc-time-axis Version: [e.g., From the command line run `python -c "import nc_time_axis; print(nc_time_axis.__version__)"`]

## Additional Context
<!-- Provide any further information to help us understand -->
<details>
<summary>Click to expand <b>this section...</b></summary>

```
Please add additional verbose information in this section e.g., code, output, tracebacks, screenshots etc
```
</details>
